rotate_x library
Classes
- RotateX
- A widget that provides image rotation functionality with optional scale adjustment
- RotateXController
- A controller class that manages rotation state and operations for an image widget
Functions
-
getImageWidthHeight(
Image image) → Future< Size?> -
toUint8List(
GlobalKey< State< imageKey) → Future<StatefulWidget> >Uint8List>